==> ovirt-engine-sdk-java-4.0.2.tar.gz: ovirt-engine-sdk-java-4.0.2/target/generated-sources/org/ovirt/engine/sdk4/services/ImageTransfersService.java <==
/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.services;

import java.io.IOException;
import java.util.List;
import org.ovirt.engine.sdk4.Request;
import org.ovirt.engine.sdk4.Response;
import org.ovirt.engine.sdk4.Service;
import org.ovirt.engine.sdk4.builders.ImageTransferBuilder;
import org.ovirt.engine.sdk4.types.ImageTransfer;

/**
 * This service manages image transfers, for performing Image I/O API in oVirt.
 * Please refer to <<services/image_transfer, image transfer>> for further
 * documentation.
 */
public interface ImageTransfersService extends Service {
    /**
     * Add a new image transfer. An image needs to be specified in order to make
     * a new transfer.
     */
    public interface AddRequest extends Request<AddRequest, AddResponse> {
        AddRequest imageTransfer(ImageTransfer imageTransfer);
        AddRequest imageTransfer(ImageTransferBuilder imageTransfer);
    }
    
    /**
     * Add a new image transfer. An image needs to be specified in order to make
     * a new transfer.
     */
    public interface AddResponse extends Response {
        ImageTransfer imageTransfer();
    }
    
    /**
     * Add a new image transfer. An image needs to be specified in order to make
     * a new transfer.
     */
    AddRequest add();
    
    /**
     * Retrieves the list of image transfers that are currently
     * being performed.
     */
    public interface ListRequest extends Request<ListRequest, ListResponse> {
    }
    
    /**
     * Retrieves the list of image transfers that are currently
     * being performed.
     */
    public interface ListResponse extends Response {
        List<ImageTransfer> imageTransfer();
    }
    
    /**
     * Retrieves the list of image transfers that are currently
     * being performed.
     */
    ListRequest list();
    
    /**
     * Returns a reference to the service that manages an
     * specific image transfer.
     */
    ImageTransferService imageTransferService(String id);
    /**
     * Service locator method, returns individual service on which the URI is dispatched.
     */
    Service service(String path);
}

==> ovirt-engine-sdk-java-4.1.4.tar.gz: ovirt-engine-sdk-java-4.1.4/target/generated-sources/org/ovirt/engine/sdk4/services/ImageTransfersService.java <==
/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.services;

import java.io.IOException;
import java.util.List;
import org.ovirt.engine.sdk4.Request;
import org.ovirt.engine.sdk4.Response;
import org.ovirt.engine.sdk4.Service;
import org.ovirt.engine.sdk4.builders.ImageTransferBuilder;
import org.ovirt.engine.sdk4.types.ImageTransfer;

/**
 * This service manages image transfers, for performing Image I/O API in oVirt.
 * Please refer to <<services/image_transfer, image transfer>> for further
 * documentation.
 */
public interface ImageTransfersService extends Service {
    /**
     * Add a new image transfer. An image needs to be specified in order to make
     * a new transfer.
     */
    public interface AddRequest extends Request<AddRequest, AddResponse> {
        AddRequest imageTransfer(ImageTransfer imageTransfer);
        AddRequest imageTransfer(ImageTransferBuilder imageTransfer);
    }
    
    /**
     * Add a new image transfer. An image needs to be specified in order to make
     * a new transfer.
     */
    public interface AddResponse extends Response {
        ImageTransfer imageTransfer();
    }
    
    /**
     * Add a new image transfer. An image needs to be specified in order to make
     * a new transfer.
     */
    AddRequest add();
    
    /**
     * Retrieves the list of image transfers that are currently
     * being performed.
     * 
     * The order of the returned list of image transfers isn't guaranteed.
     */
    public interface ListRequest extends Request<ListRequest, ListResponse> {
    }
    
    /**
     * Retrieves the list of image transfers that are currently
     * being performed.
     * 
     * The order of the returned list of image transfers isn't guaranteed.
     */
    public interface ListResponse extends Response {
        List<ImageTransfer> imageTransfer();
    }
    
    /**
     * Retrieves the list of image transfers that are currently
     * being performed.
     * 
     * The order of the returned list of image transfers isn't guaranteed.
     */
    ListRequest list();
    
    /**
     * Returns a reference to the service that manages an
     * specific image transfer.
     */
    ImageTransferService imageTransferService(String id);
    /**
     * Service locator method, returns individual service on which the URI is dispatched.
     */
    Service service(String path);
}
